
# Changelog
All notable changes to WuttaTell will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.2.0 (2025-08-10)

### Feat

- add native API client for common submission use case

### Fix

- add dependency for `requests`
- remove `submit_uuid` from telemetry config profile
- tweak log verbiage

## v0.1.0 (2025-08-09)

### Feat

- basic telemetry collection/submission feature
